/*
 * Copyright/Copyleft (C) 2012 Orest Tarasiuk <orest.tarasiuk@tum.de>
 *
 * This file is part of Gnome Shell Extension Blank on Lid (GSEBL).
 *
 * GSEBL is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * GSEBL is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GSEBL.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Forked from https://extensions.gnome.org/extension/237/desktop-icons-switch/
 *
 */

const St = imports.gi.St;
const Main = imports.ui.main;
const PopupMenu = imports.ui.popupMenu;
const Lang = imports.lang;
const Gio = imports.gi.Gio;
const ExtensionUtils = imports.misc.extensionUtils;
const Me = ExtensionUtils.getCurrentExtension();
const Lib = Me.imports.lib;

let menuItemBat, menuItemAc, userMenu, iconSetting;
let schema, keyBat, keyAc;
let statusBat, statusAc, statusPrio;
let statusBatOrig = "blank";
let statusAcOrig = "blank";
let switchTextBat = "Blank on Lid (Bat)";
let switchTextAc = "Blank on Lid (AC)";
let showBat = true;
let showAc = true;

schema = "org.gnome.settings-daemon.plugins.power";
keyBat = "lid-close-battery-action";
keyAc = "lid-close-ac-action";

function init()
{
    userMenu = Main.panel._statusArea.userMenu;
    settings = Lib.getSettings(Me);
}

function enable()
{
    showBat = settings.get_boolean("showbat");
    showAc = settings.get_boolean("showac");
    switchTextBat = settings.get_string("switchtextbat");
    switchTextAc = settings.get_string("switchtextac");

    iconSetting = new Gio.Settings({
        schema: schema
    });
    statusBat = iconSetting.get_string(keyBat);
    statusAc = iconSetting.get_string(keyAc);

    if (showBat){
        menuItemBat = new PopupMenu.PopupSwitchMenuItem(
            _(switchTextBat), statusBat == "blank");
        userMenu.menu.addMenuItem(menuItemBat, 2);
        menuItemBat.connect('toggled', Lang.bind(userMenu, function() {
            statusBat = iconSetting.get_string(keyBat);
            if (statusBat !== "blank"){
                statusBatOrig = statusBat.toString();
                iconSetting.set_string(keyBat, "blank");
            }
            else if (statusBat == "blank") {
                iconSetting.set_string(keyBat, statusBatOrig);
            }
        }));

    }
    if (showAc){
        menuItemAc = new PopupMenu.PopupSwitchMenuItem(
            _(switchTextAc), statusAc == "blank");
        userMenu.menu.addMenuItem(menuItemAc, 2);
        menuItemAc.connect('toggled', Lang.bind(userMenu, function() {
            statusAc = iconSetting.get_string(keyAc);
            if (statusAc !== "blank"){
                statusAcOrig = statusAc.toString();
                iconSetting.set_string(keyAc, "blank");
            }
            else if (statusAc == "blank") {
                iconSetting.set_string(keyAc, statusAcOrig);
            }
        }));
    }
}

function disable()
{
    if (menuItemBat) {
        menuItemBat.destroy();
    }
    if (menuItemAc) {
        menuItemAc.destroy();
    }
}